@@ -20,7 +20,7 @@ chain = itertools.chain
 iterchain = itertools.chain.from_iterable
 
 from clu.constants.consts import (λ, φ, # type: ignore
-                                  BASEPATH, BUILTINS, PROJECT_NAME,
+                                  APPNAME, BASEPATH, BUILTINS,
                                   QUALIFIER,
                                   NoDefault, pytuple)
 from clu.constants.exceptions import BadDotpathWarning, ExportError, ExportWarning
@@ -64,6 +64,25 @@ def itermoduleids(module):
 # of the `pickle.whichmodule(…)` function (!)
 sysmods = lambda: reversed(tuple(frozenset(sys.modules.values())))
 
+class Modulespace(object):
+    
+    """ Makes top-level python modules available as an attribute,
+        importing them on first access.
+        
+        Q.v. pypy/rpython source supra:
+            http://bit.ly/lazy-borg-modulespace
+    """
+    
+    def __init__(self):
+        self.__dict__ = sys.modules
+    
+    def __getattr__(self, key):
+        try:
+            module = importlib.import_module(key)
+        except (ModuleNotFoundError, ImportError):
+            raise AttributeError("could not import module: %s" % key)
+        return module
+
 @cache
 def search_by_id(thingID):
     """ Cached function to find the name of a thing, according
@@ -161,7 +180,7 @@ def determine_name(thing, name=None, try_repr=False):
         if hasattr(thing, '__name__'):
             name = thing.__name__
         elif hasattr(thing, '__qualname__'):
-            name = thing.__qualname__
+            name = thing.__qualname__.rpartition(QUALIFIER)[-1]
     # We likely have something by now:
     if name is not None:
         return name
@@ -293,7 +312,7 @@ class Registry(abc.ABC, metaclass=clu.abstract.Slotted):
             Attempting to unregister the core CLU application’s exporter
             is not allowed and will raise a KeyError.
         """
-        if appname == PROJECT_NAME:
+        if appname == APPNAME:
             raise KeyError("Can’t unregister the core application exporter")
         cls = classes.pop(appname, None)
         if cls:
@@ -529,7 +548,13 @@ class ExporterBase(collections.abc.MutableMapping,
                     named = search_for_name(thing)
                 if named is None:
                     raise ExportError(type(self).messages['noname'] % id(thing))
-                thing.__name__ = thing.__qualname__ = named
+                qname = getattr(thing, '__qualname__')
+                if qname:
+                    setattr(thing, '__qualname__',
+                            qname.replace(
+                            getattr(thing, '__name__'),
+                                    named))
+                thing.__name__ = named
                 thing.__lambda_name__ = dname # To recall the lambda’s genesis
                 if dname == φ and self.dotpath is not None:
                     thing.__module__ = str(self.dotpath) # Reset __module__ for phi-types
@@ -612,6 +637,12 @@ class ExporterBase(collections.abc.MutableMapping,
         """
         return search_by_id.cache_info()
     
+    def module(self):
+        """ Shortcut to get the parent module for the exporter. """
+        if self.dotpath is not None:
+            return importlib.import_module(self.dotpath)
+        return None
+    
     def __enter__(self):
         return self.decorator()
     
@@ -679,7 +710,7 @@ class ExporterBase(collections.abc.MutableMapping,
                                                      'unregister'),
                            super(ExporterBase, self).__dir__()))
 
-class Exporter(ExporterBase, prefix=BASEPATH, appname=PROJECT_NAME):
+class Exporter(ExporterBase, prefix=BASEPATH, appname=APPNAME):
     
     """ A class representing a list of things for a module to export.
         
