@@ -16,7 +16,10 @@ Dev Notes:
 - Mac OS X: http://developer.apple.com/documentation/MacOSX/Conceptual/BPFileSystem/index.html
 - XDG spec for Un*x: https://standards.freedesktop.org/basedir-spec/basedir-spec-latest.html
 """
+from functools import lru_cache
 
+import collections
+import collections.abc
 import sys
 import os
 import platform
@@ -33,12 +36,14 @@ from clu.exporting import Exporter
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
 
+cache = lambda function: export(lru_cache(maxsize=16, typed=True)(function))
+
 # Module-specific version/version-info:
 __version__ = "2.2.0"
 __version_info__ = VersionInfo(__version__)
 
 @export
-class AppDirs(object):
+class AppDirs(collections.abc.Hashable):
     
     """ Convenience wrapper for getting application dirs. """
     
@@ -75,13 +80,13 @@ class AppDirs(object):
         # The name of the application:
         self.appname = appname
         
-        # These next three data only matter on Windows:
+        # The next three data are only relevant on Windows:
         self.appauthor = appauthor
         self.roaming = bool(roaming)
         self.multipath = bool(multipath)
         
         # System and Version can be specified as instances of the System enum
-        # or of clu.version.VersuionInfo, respectively:
+        # or of clu.version.VersionInfo, respectively:
         self.system = system and System.match(system) or SYSTEM
         self.version = version and str(version) or None
         self.version_info = version and VersionInfo(version) or None
@@ -94,9 +99,6 @@ class AppDirs(object):
         else:
             # On non-Windows platforms, warn when options relevant only to
             # Windows-y OSes have been specified:
-            if appauthor is not None:
-                warnings.warn("The “appauthor” value is currently only used under Windows",
-                              UnusedValueWarning, stacklevel=2)
             if roaming:
                 warnings.warn("The “roaming” option is currently only used under Windows",
                               UnusedValueWarning, stacklevel=2)
@@ -164,6 +166,11 @@ class AppDirs(object):
     def __bytes__(self):
         return bytes(self.to_string(), encoding=ENCODING)
     
+    def __hash__(self):
+        return hash(self.to_string()) & \
+               hash(self.appname) & \
+               hash(self.version_info.to_string())
+    
     @property
     def user_data_dir(self):
         """ The userland application-specific data directory """
@@ -735,6 +742,22 @@ def get_win_folder_with_jna(csidl):
     
     return directory
 
+@cache
+def clu_appdirs(system=System.LINUX2, versioning=True):
+    """ Retrieve an AppDirs instance specific to the CLU project """
+    import clu
+    from clu.constants import consts
+    from clu.version import version_info
+    
+    # Determine version value:
+    version = bool(versioning) and version_info.to_string() or None
+    
+    # Return an AppDirs instance for project CLU:
+    return AppDirs(consts.PROJECT_NAME,
+                   clu.__author__,
+                   version=version,
+                   system=system)
+
 export(System)
 export(CSIDL)
 export(SYSTEM,  name='SYSTEM')
@@ -745,16 +768,20 @@ __all__, __dir__ = exporter.all_and_dir()
 def test():
     """ Inline tests for appdirectories """
     from clu.repl.ansi import print_separator
+    from clu.version import version_info
     
     appname = "MyApp"
     appauthor = "MyCompany"
+    appversion = "1.0"
     
-    props = ("system", "version", "version_info",
-             "site_config_dir", "site_data_dir",
-             "user_cache_dir", "user_config_dir",
-                               "user_data_dir",
-                               "user_log_dir",
-                               "user_state_dir")
+    dirs = ("site_config", "site_data",
+             "user_cache", "user_config",
+                           "user_data",
+                           "user_log",
+                           "user_state")
+    
+    props = ("system", "version", "version_info") \
+          + tuple(f"{dirname}_dir" for dirname in dirs)
     
     print(f"-- “appdirectories” __version__: {__version__} --")
     print()
@@ -763,35 +790,69 @@ def test():
     for system in System:
         
         print_separator()
-        default = (system is SYSTEM) and "(DEFAULT)" or ""
-        print(f"-- System: {system.to_string()} {default}")
+        current = system.is_current and "(CURRENT SYSTEM)" or ""
+        print(f"-- System: {system.to_string()} {current}")
         # print()
         
         if (system is not System.WIN32) or ((system is System.WIN32) \
                                         and (SYSTEM is System.WIN32)):
             
             print("-- app dirs (with optional 'version')")
-            dirs = AppDirs(appname, appauthor, version="1.0", system=system)
+            appdirs = AppDirs(appname, appauthor, version=appversion, system=system)
             for prop in props:
-                print("%20s : %s" % (prop, getattr(dirs, prop)))
+                assert hasattr(appdirs, prop)
+                if prop.endswith('dir') and prop != "site_config_dir":
+                    assert appversion in str(getattr(appdirs, prop))
+                print("%20s : %s" % (prop, getattr(appdirs, prop)))
+            for dirname in dirs:
+                assert type(getattr(appdirs, dirname)) is Directory
             print()
             
             print("-- app dirs (without optional 'version')")
-            dirs = AppDirs(appname, appauthor, system=system)
+            appdirs = AppDirs(appname, appauthor, system=system)
             for prop in props:
-                print("%20s : %s" % (prop, getattr(dirs, prop)))
+                assert hasattr(appdirs, prop)
+                print("%20s : %s" % (prop, getattr(appdirs, prop)))
+            for dirname in dirs:
+                assert type(getattr(appdirs, dirname)) is Directory
             print()
             
             print("-- app dirs (without optional 'appauthor')")
-            dirs = AppDirs(appname, system=system)
+            appdirs = AppDirs(appname, system=system)
             for prop in props:
-                print("%20s : %s" % (prop, getattr(dirs, prop)))
+                assert hasattr(appdirs, prop)
+                print("%20s : %s" % (prop, getattr(appdirs, prop)))
+            for dirname in dirs:
+                assert type(getattr(appdirs, dirname)) is Directory
             print()
             
             print("-- app dirs (with disabled 'appauthor')")
-            dirs = AppDirs(appname, appauthor=False, system=system)
+            appdirs = AppDirs(appname, appauthor=False, system=system)
             for prop in props:
-                print("%20s : %s" % (prop, getattr(dirs, prop)))
+                assert hasattr(appdirs, prop)
+                print("%20s : %s" % (prop, getattr(appdirs, prop)))
+            for dirname in dirs:
+                assert type(getattr(appdirs, dirname)) is Directory
+            print()
+            
+            print("-- CLU-specific AppDirs instance (from “clu_appdirs(…)”)")
+            appdirs = clu_appdirs(system=system, versioning=False)
+            for prop in props:
+                assert hasattr(appdirs, prop)
+                print("%20s : %s" % (prop, getattr(appdirs, prop)))
+            for dirname in dirs:
+                assert type(getattr(appdirs, dirname)) is Directory
+            print()
+            
+            print("-- CLU-specific versioned AppDirs instance (from “clu_appdirs(…)”)")
+            appdirs = clu_appdirs(system=system)
+            for prop in props:
+                assert hasattr(appdirs, prop)
+                if prop.endswith('dir') and prop != "site_config_dir":
+                    assert version_info.to_string() in str(getattr(appdirs, prop))
+                print("%20s : %s" % (prop, getattr(appdirs, prop)))
+            for dirname in dirs:
+                assert type(getattr(appdirs, dirname)) is Directory
             print()
         
         else:
