@@ -26,7 +26,7 @@ from clu.repr import stringify
 from clu.sanitizer import utf8_encode
 from clu.typology import isnotpath, isvalidpath
 from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
-from clu.fs.misc import re_searcher, suffix_searcher, re_excluder
+from clu.fs.misc import re_matcher, re_searcher, suffix_searcher, re_excluder
 from clu.fs.misc import swapext, u8str, extension
 from clu.exporting import Exporter, path_to_dotpath
 
@@ -698,8 +698,7 @@ class TemporaryName(collections.abc.Hashable,
     def __hash__(self):
         return hash((self._name, self.exists))
 
-non_dotfile_match = re.compile(r"^[^\.]").match
-non_dotfile_matcher = lambda p: non_dotfile_match(p.name)
+non_dotfile_matcher = re_matcher(r"^[^\.]")
 
 @export
 class Directory(collections.abc.Hashable,
@@ -924,10 +923,12 @@ class Directory(collections.abc.Hashable,
             Specify an optional “suffix” parameter to filter the list by a
             particular file suffix (leading dots unnecessary but unharmful).
         """
+        if not self.exists:
+            return tuple()
         with os.scandir(self.realpath(source)) as iterscan:
             return tuple(filter(suffix_searcher(suffix),
-                        (direntry.name for direntry in filter(non_dotfile_matcher,
-                                                              iterscan))))
+                         filter(non_dotfile_matcher,
+                        (direntry.name for direntry in iterscan))))
     
     def ls_la(self, suffix=None, source=None):
         """ List all files, including files whose name starts with a dot.
@@ -943,6 +944,8 @@ class Directory(collections.abc.Hashable,
             commands I ever learned, and it reads better than `ls_a()` which
             I think looks awkward and goofy.)
         """
+        if not self.exists:
+            return tuple()
         with os.scandir(self.realpath(source)) as iterscan:
             return tuple(filter(suffix_searcher(suffix),
                         (direntry.name for direntry in iterscan)))
@@ -1174,7 +1177,7 @@ class Directory(collections.abc.Hashable,
         excluder = re_excluder(excludes)
         searcher = suffix_searcher(suffix)
         dotpaths = []
-        target = self.subdirectory(subdir or os.path.curdir, source)
+        target = self.subdirectory(subdir or os.curdir, source)
         # Use a call to “os.walk(…)” directly to allow modification of
         # the “dirs” list in-place:
         for root, dirs, files in os.walk(target):
@@ -1194,9 +1197,9 @@ class Directory(collections.abc.Hashable,
             excluding anything matching any of the “excludes” strings
         """
         excluder = re_excluder(excludes)
-        searcher = re_searcher(re.escape(os.path.extsep))
+        searcher = re_searcher(re.escape(os.extsep))
         suffixes = collections.Counter()
-        target = self.subdirectory(subdir or os.path.curdir, source)
+        target = self.subdirectory(subdir or os.curdir, source)
         # Use a call to “os.walk(…)” directly to allow modification of
         # the “dirs” list in-place:
         for root, dirs, files in os.walk(target):
@@ -1207,6 +1210,17 @@ class Directory(collections.abc.Hashable,
                             filter(searcher, files)))))
         return suffixes
     
+    def suffixes(self, subdir=None,
+                       source=None,
+                       excludes=('~', '#', 'ds_store', '.git')):
+        """ Return a generator over all the file suffixes of all files
+            found recursively within the given subdirectory, excluding
+            anything matching any of the “excludes” strings
+        """
+        yield from self.suffix_histogram(subdir=subdir,
+                                         source=source,
+                                       excludes=excludes).keys()
+    
     def close(self):
         """ Stub method -- always returns True: """
         return True
@@ -1248,24 +1262,24 @@ class Directory(collections.abc.Hashable,
         return self.exists
     
     def __iter__(self):
-        out = self.exists \
-              and (k.name for k in os.scandir(
-                                   os.path.realpath(self.name))) \
-               or iter(tuple())
-        yield from out
+        if self.exists:
+            with os.scandir(os.path.realpath(self.name)) as iterscan:
+                yield from (k.name for k in iterscan)
+        else:
+            yield from iter(tuple())
     
     def __reversed__(self):
-        out = self.exists \
-              and (k.name for k in reversed(os.scandir(
-                                   os.path.realpath(self.name)))) \
-               or iter(tuple())
-        yield from out
+        if self.exists:
+            with os.scandir(os.path.realpath(self.name)) as iterscan:
+                yield from (k.name for k in reversed(iterscan))
+        else:
+            yield from iter(tuple())
     
     def __len__(self):
-        return self.exists \
-               and len(os.listdir(
-                       os.path.realpath(self.name))) \
-                or 0
+        if not self.exists:
+            return 0
+        return len(os.listdir(
+                   os.path.realpath(self.name)))
     
     def __getitem__(self, filename):
         pth = self.subpath(filename, requisite=True)
