@@ -109,8 +109,8 @@ class MetaRegistry(Extensible):
                 cls = Registry.monomers[appname].pop(qualified_name)
                 if qualified_name in sys.modules:
                     del sys.modules[qualified_name]
-                if hasattr(cls, 'exporter'):
-                    cls.exporter.unregister(qualified_name)
+                if hasattr(cls, consts.EXPORTER_NAME):
+                    getattr(cls, consts.EXPORTER_NAME).unregister(qualified_name)
                 importlib.invalidate_caches()
                 return bool(cls)
         return False
@@ -481,7 +481,8 @@ class MetaModule(MetaRegistry):
         if cls.appname is not None and not name.endswith('Module'):
             if ExporterRegistry.has_appname(cls.appname):
                 ExporterClass = ExporterRegistry[cls.appname]
-                cls.exporter = ExporterClass(dotpath=cls.qualname)
+                setattr(cls, consts.EXPORTER_NAME,
+                             ExporterClass(dotpath=cls.qualname))
                 
                 # Invoke all of our argument sinks against the
                 # Exporter instance’s “export(…)” function:
@@ -585,8 +586,8 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
     
     def __dir__(self):
         cls = type(self)
-        if hasattr(cls, 'exporter'):
-            return cls.exporter.dir_function()()
+        if hasattr(cls, consts.EXPORTER_NAME):
+            return getattr(cls, consts.EXPORTER_NAME).dir_function()()
         names = chain(cls.__dict__.keys(),
                       super(ModuleBase, self).__dir__())
         return sorted(frozenset(names) - DO_NOT_INCLUDE)
@@ -741,7 +742,7 @@ def initialize_types(appname, appspace='app'):
     
     return Module, Finder, Loader
 
-Module, Finder, Loader = initialize_types(consts.PROJECT_NAME)
+Module, Finder, Loader = initialize_types(consts.APPNAME)
 
 @export
 class ChainModuleMap(clu.dicts.ChainMap):
@@ -1023,12 +1024,12 @@ def test():
     def test_one():
         """ Class-module basics """
         
-        m = Module(consts.PROJECT_NAME)
+        m = Module(consts.APPNAME)
         assert m
-        assert m.appname == consts.PROJECT_NAME
+        assert m.appname == consts.APPNAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
-        assert nameof(m) == consts.PROJECT_NAME
+        assert nameof(m) == consts.APPNAME
     
     @inline
     def test_two():
@@ -1065,7 +1066,7 @@ def test():
         pprint(tuple(all_registered_modules()))
         print()
         
-        m = Module(consts.PROJECT_NAME)
+        m = Module(consts.APPNAME)
         
         assert len(Registry.monomers) > 0
         
@@ -1076,10 +1077,10 @@ def test():
         else:
             pass
         
-        assert m.appname == consts.PROJECT_NAME
+        assert m.appname == consts.APPNAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
-        assert nameof(m) == consts.PROJECT_NAME
+        assert nameof(m) == consts.APPNAME
         
         print("mro(m):")
         pprint(mro(m))
@@ -1152,7 +1153,7 @@ def test():
     def test_five():
         """ Proxy-module properties and value resolution """
         
-        overrides = dict(PROJECT_NAME='yodogg',
+        overrides = dict(APPNAME='yodogg',
                          PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
                          BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
         
@@ -1163,7 +1164,7 @@ def test():
         
         assert overridden.USER == consts.USER
         assert overridden.BUILTINS == consts.BUILTINS
-        assert overridden.PROJECT_NAME == 'yodogg'
+        assert overridden.APPNAME == 'yodogg'
         assert overridden.PROJECT_PATH.endswith('yodogg')
         assert overridden.BASEPATH.endswith('yodogg')
         
@@ -1175,7 +1176,7 @@ def test():
     def test_five_point_five():
         """ Proxy-module fallback callable check """
         
-        overrides = dict(PROJECT_NAME='yodogg',
+        overrides = dict(APPNAME='yodogg',
                          PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
                          BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
         
@@ -1191,7 +1192,7 @@ def test():
         
         assert overridden.USER == consts.USER
         assert overridden.BUILTINS == consts.BUILTINS
-        assert overridden.PROJECT_NAME == 'yodogg'
+        assert overridden.APPNAME == 'yodogg'
         assert overridden.PROJECT_PATH.endswith('yodogg')
         assert overridden.BASEPATH.endswith('yodogg')
         
@@ -1205,7 +1206,7 @@ def test():
     def test_six():
         """ Polymer-type caching and “initialize_types(…)” checks """
         
-        Module0, Finder0, Loader0 = initialize_types(consts.PROJECT_NAME)
+        Module0, Finder0, Loader0 = initialize_types(consts.APPNAME)
         
         assert Finder is Finder0
         assert Loader is Loader0
@@ -1214,7 +1215,7 @@ def test():
         assert isinstance(Module0.__loader__, Loader0)
         assert isinstance(Finder0.loader, Loader0)
         
-        Module1, Finder1, Loader1 = initialize_types(consts.PROJECT_NAME, appspace='aux')
+        Module1, Finder1, Loader1 = initialize_types(consts.APPNAME, appspace='aux')
         
         assert Finder is Finder1
         assert Loader is Loader1
