@@ -8,10 +8,13 @@ import importlib.machinery
 import inspect
 import pickle
 
-from clu.constants.consts import λ, φ, BASEPATH, QUALIFIER, NoDefault
+from clu.constants.consts import λ, φ
+from clu.constants.consts import BASEPATH, QUALIFIER, NoDefault
+
 from clu.exporting import (path_to_dotpath, determine_name,
                                             search_for_name,
                                             search_for_module)
+
 from clu.exporting import Exporter, Registry
 
 exporter = Exporter(path=__file__)
@@ -109,16 +112,16 @@ def moduleof(thing, default=NoDefault):
 
 # MODULE INSPECTOR PREDICATES: determine what undergirds a module object
 
+EXTENSION_SUFFIXES = tuple(suffix.lstrip(QUALIFIER) \
+                       for suffix \
+                        in importlib.machinery.EXTENSION_SUFFIXES)
+
 isbuiltin = lambda thing: moduleof(thing) == 'builtins'
 
 suffix = lambda filename: QUALIFIER in filename \
             and filename.rpartition(QUALIFIER)[-1] \
              or ''
 
-EXTENSION_SUFFIXES = tuple(suffix.lstrip(QUALIFIER) \
-                       for suffix \
-                        in importlib.machinery.EXTENSION_SUFFIXES)
-
 @export
 def isnativemodule(module):
     """ isnativemodule(thing) → boolean predicate, True if `module`
@@ -211,17 +214,17 @@ def qualified_import(qualified):
 
 @export
 def qualified_name_tuple(thing):
-    """ Get the module/package and thing-name for a class or module.
-        e.g. ('instakit.processors.halftone', 'FloydSteinberg')
+    """ Get the thing-name and module/package name for a class or module.
+        e.g. ('FloydSteinberg', 'instakit.processors.halftone')
     """
-    return moduleof(thing), nameof(thing)
+    return nameof(thing), moduleof(thing)
 
 @export
 def qualified_name(thing):
     """ Get a qualified thing-name for a thing.
         e.g. 'instakit.processors.halftone.FloydSteinberg'
     """
-    module_name, thing_name = qualified_name_tuple(thing)
+    thing_name, module_name = qualified_name_tuple(thing)
     qualname = dotpath_join(module_name, thing_name)
     return qualname
 
@@ -294,6 +297,87 @@ class rename(collections.abc.Callable):
             return putative(*args, **kwargs)
         return renamed
 
+@export
+def duplicate(target, name, gs=None, **attributes):
+    """ Make a renamed copy of a target function.
+        
+        Q.v. pypy/rpython source supra:
+            http://bit.ly/func-with-new-name
+    """
+    from clu.predicates import allpyattrs, pyattr, pyattrs, unwrap
+    from clu.typespace import types
+    from clu.typology import ΛΛ
+    
+    # Sanity-check arguments:
+    if not ΛΛ(target):
+        raise TypeError("“duplicate(…)” requires a function target")
+    if not name:
+        raise NameError("“duplicate(…)” requires a new function name")
+    if not name.isidentifier():
+        raise NameError(f"bad name “{name}” passed to “duplicate(…)”")
+    
+    # For bound methods, delegate the duplication
+    # to the underlying function:
+    if allpyattrs(target, 'func', 'self'):
+        if ΛΛ(pyattr(target, 'func')):
+            return duplicate(target.__func__, name, gs=gs, **attributes)
+    
+    # Create a new function object:
+    function = types.Function(target.__code__,
+                              gs or target.__globals__,
+                              name, target.__defaults__,
+                                    target.__closure__)
+    
+    # Update function dictionary:
+    function.__dict__ = { **function.__dict__,
+                          **target.__dict__,
+                          **attributes }
+    
+    # Add keyword defaults and/or annotations:
+    if target.__annotations__:
+        function.__annotations__ = target.__annotations__.copy()
+    
+    if target.__kwdefaults__:
+        function.__kwdefaults__  = target.__kwdefaults__.copy()
+    
+    # Replace the docstring:
+    if target.__doc__:
+        function.__doc__         = inspect.getdoc(target)
+    
+    # Replace only the relevant part of the qualname:
+    if allpyattrs(target, 'qualname', 'name'):
+        qnm, nm = pyattrs(target, 'qualname', 'name')
+        function.__qualname__    = qnm.replace(nm, name)
+    
+    # Copy the “lambda_name”, if present:
+    if pyattr(target, 'lambda_name'):
+        function.__lambda_name__ = target.__lambda_name__
+    elif target.__name__ in (λ, φ):
+        function.__lambda_name__ = target.__name__
+    
+    # Duplicate the wrapped function, if present:
+    if ΛΛ(pyattr(target, 'wrapped')):
+        function.__wrapped__ = duplicate(unwrap(target),
+                                       f"{name}_target", gs=gs,
+                                       **attributes)
+    # Return anew:
+    return function
+
+@export
+def renamer(name, gs=None, **attributes):
+    """ A decorator which renames the target function. Usage:
+        
+            @renamer('yo_dogg')
+            def no_dogg():
+                # …
+        
+        Q.v. pypy/rpython source supra:
+            http://bit.ly/func-with-new-name
+    """
+    def decoration(target):
+        return duplicate(target, name, gs=gs, **attributes)
+    return decoration
+
 @export
 def split_abbreviations(s):
     """ Split a string into a tuple of its unique constituents,
