@@ -204,14 +204,19 @@ rmro        = reverse(mro)
 isancestor  = lambda cls, ancestor=object: isclasstype(cls) and (ancestor in mro(cls))
 isorigin    = lambda cls, original=object: isclasstype(cls) and isancestor(origin(cls), typeof(original))
 
-class ObjectType(object):
-    """ Base type for programmatically created new types """
+@export
+class Base(object):
+    """ Base type for programmatically created new types.
+        
+        Can be accessed as an attribute of “newtype(…)”, e.g. “newtype.Base”;
+        q.v. the “newtype(…)” function sub.
+    """
     pass
 
 @cache
 def newtype(name, *bases, metaclass=None, attributes=None, **keywords):
     """ newtype(name, *bases, metaclass=None, attributes=None, **keywords)
-        → Shortcut for “type(name, tuple(bases) or (ObjectType,), dict(attributes))”
+        → Shortcut for “type(name, tuple(bases) or (newtype.Base,), dict(attributes))”
         
         q.v. https://docs.python.org/3/library/types.html#dynamic-type-creation supra.
     """
@@ -220,7 +225,7 @@ def newtype(name, *bases, metaclass=None, attributes=None, **keywords):
     
     # Default arguments:
     if not bases:
-        bases = (ObjectType,)
+        bases = (newtype.Base,)
     if attributes is None:
         attributes = {}
     if ismetaclass(metaclass):
@@ -241,6 +246,10 @@ def newtype(name, *bases, metaclass=None, attributes=None, **keywords):
                                  kwds=kwds,
                                  exec_body=lambda ns: ns.update(namespace))
 
+# Hang the base type off of the “newtype(…)” function,
+# for E-Z access:
+newtype.Base = Base
+
 # ENUM PREDICATES: `isenum(…)` predicate; `enumchoices(…)` to return a tuple
 # of strings naming an enum’s choices (like duh)
 
@@ -304,12 +313,20 @@ class Partial(partial):
     def __init__(self, *args, **kwargs):
         """ Initialize a new Partial object, with a predicate and a function """
         # N.B. The real action seems to happen in partial.__new__(…)
-        # Name the Partial instance, as if it’s a phi-type:
-        self.__name__ = self.__qualname__ = φ
         try:
             super(Partial, self).__init__(*args, **kwargs)
         except:
             super(Partial, self).__init__() # type: ignore
+        
+        # Name the Partial instance, as if it’s a phi-type:
+        qname = or_none(self, '__qualname__')
+        if qname:
+            setattr(self, '__qualname__',
+                    qname.replace(
+                    getattr(self, '__name__'), φ))
+        else:
+            self.__qualname__ = φ
+        self.__name__ = φ
     
     @property
     def predicate(self):
