@@ -97,8 +97,8 @@ class TestExporting(object):
         from clu.predicates import haspyattr
         
         # Walk the importables:
-        submodules = Directory(consts.BASEPATH).importables(consts.PROJECT_NAME)
-        clsmodules = tuple(clsmodule.qualname for clsmodule in modules_for_appname(consts.PROJECT_NAME))
+        submodules = Directory(consts.BASEPATH).importables(consts.APPNAME)
+        clsmodules = tuple(clsmodule.qualname for clsmodule in modules_for_appname(consts.APPNAME))
         
         # Sanity-check the number of modules:
         assert len(clumods) <= len(submodules) + len(clsmodules)
@@ -284,8 +284,8 @@ class TestExporting(object):
         assert 'i_heard' in exporter
         assert yo_dogg.__name__ == 'yo_dogg'
         assert i_heard.__name__ == 'i_heard'
-        assert yo_dogg.__qualname__ == 'yo_dogg'
-        assert i_heard.__qualname__ == 'i_heard'
+        assert yo_dogg.__qualname__.endswith('yo_dogg')
+        assert i_heard.__qualname__.endswith('i_heard')
         assert nameof(yo_dogg) == 'yo_dogg'
         assert nameof(i_heard) == 'i_heard'
         
@@ -318,8 +318,8 @@ class TestExporting(object):
         assert 'i_heard' in exporter
         assert yo_dogg.__name__ == 'yo_dogg'
         assert i_heard.__name__ == 'i_heard'
-        assert yo_dogg.__qualname__ == 'yo_dogg'
-        assert i_heard.__qualname__ == 'i_heard'
+        assert yo_dogg.__qualname__.endswith('yo_dogg')
+        assert i_heard.__qualname__.endswith('i_heard')
         assert nameof(yo_dogg) == 'yo_dogg'
         assert nameof(i_heard) == 'i_heard'
         
