@@ -8,7 +8,7 @@ class TestImporting(object):
     def test_proxy_module_for_reals(self, consts):
         from clu.importing import ProxyModule, Registry
         
-        overrides = dict(PROJECT_NAME='yodogg',
+        overrides = dict(APPNAME='yodogg',
                          PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
                          BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
         
@@ -21,7 +21,7 @@ class TestImporting(object):
             
             assert overridden.USER == consts.USER
             assert overridden.BUILTINS == consts.BUILTINS
-            assert overridden.PROJECT_NAME == 'yodogg'
+            assert overridden.APPNAME == 'yodogg'
             assert overridden.PROJECT_PATH.endswith('yodogg')
             assert overridden.BASEPATH.endswith('yodogg')
             
@@ -46,7 +46,7 @@ class TestImporting(object):
         from clu.importing import Module, Registry
         from clu.typology import ismodule, ismapping
         
-        overrides = dict(PROJECT_NAME='yodogg',
+        overrides = dict(APPNAME='yodogg',
                          PROJECT_PATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg/yodogg',
                          BASEPATH='/Users/fish/Dropbox/CLU/clu/tests/yodogg')
         
@@ -136,7 +136,7 @@ class TestImporting(object):
             
             assert overridden.USER == consts.USER
             assert overridden.BUILTINS == consts.BUILTINS
-            assert overridden.PROJECT_NAME == 'yodogg'
+            assert overridden.APPNAME == 'yodogg'
             assert overridden.PROJECT_PATH.endswith('yodogg')
             assert overridden.BASEPATH.endswith('yodogg')
             
@@ -157,7 +157,7 @@ class TestImporting(object):
                 Registry.unregister(clsmod.appname,
                                     clsmod.qualname)
     
-    def test_module_export_within_execute(self):
+    def test_module_export_within_execute(self, consts):
         from clu.importing import Module, Registry, DO_NOT_INCLUDE
         from clu.exporting import Exporter
         
@@ -206,6 +206,8 @@ class TestImporting(object):
             assert repr(derived) == "<class-module ‘clu.app.DerivedWithExecute’ from “clu.app”>"
             assert derived.yo == 'dogg'
             
+            assert hasattr(derived, consts.EXPORTER_NAME)
+            
             assert type(derived.exporter) is Exporter
             assert len(derived.exporter) == len(dir(derived))
             assert derived.exporter.dotpath == derived.qualname
@@ -241,12 +243,12 @@ class TestImporting(object):
         from clu.naming import nameof
         from clu.importing import Registry, Module
         
-        m = Module(consts.PROJECT_NAME)
+        m = Module(consts.APPNAME)
         assert m
-        assert m.appname == consts.PROJECT_NAME
+        assert m.appname == consts.APPNAME
         assert m.appspace == 'app'
         assert m.__name__ == 'clu.app.clu'
-        assert nameof(m) == consts.PROJECT_NAME
+        assert nameof(m) == consts.APPNAME
         
         assert len(Registry.monomers) > 0
         assert len(m.monomers) == 0
@@ -396,7 +398,7 @@ class TestImporting(object):
             from clu.importing import Registry
             Registry.unregister(derived.appname, derived.qualname)
     
-    def test_derived_import_with_export(self):
+    def test_derived_import_with_export(self, consts):
         from clu.importing import Module, Registry, DO_NOT_INCLUDE
         from clu.exporting import Exporter
         export = None # SHUT UP, PYFLAKES!!
@@ -433,6 +435,8 @@ class TestImporting(object):
             assert repr(derived) == "<class-module ‘clu.app.AnotherDerived’ from “clu.app”>"
             assert derived.yo == 'dogg'
             
+            assert hasattr(derived, consts.EXPORTER_NAME)
+            
             assert type(derived.exporter) is Exporter
             assert len(derived.exporter) == len(dir(derived))
             assert derived.exporter.dotpath == derived.qualname
