@@ -60,8 +60,8 @@ class TestRepr(object):
         assert strfield(Decimal(3.14)).startswith("3.1400000000000001243")
         assert strfield(Things).startswith("‘Things<(YO, DOGG, I, HEARD) @ ")
     
-    def test_chop_instance_repr(self, dirname):
-        from clu.repr import chop_instance_repr, INSTANCE_DELIMITER
+    def test_chop_instance_repr(self, dirname, consts):
+        from clu.repr import chop_instance_repr
         data = dirname.subdirectory('data')
         
         assert chop_instance_repr(dirname)       == "Directory(name=“/Users/fish/Dropbox/CLU/clu/tests”, exists=«True»)"
@@ -71,13 +71,32 @@ class TestRepr(object):
         assert repr(dirname).startswith(chop_instance_repr(dirname))
         assert repr(data).startswith(chop_instance_repr(data))
         
-        assert repr(dirname).find(INSTANCE_DELIMITER) != -1
-        assert repr(data).find(INSTANCE_DELIMITER) != -1
-        assert chop_instance_repr(dirname).find(INSTANCE_DELIMITER) == -1
-        assert chop_instance_repr(data).find(INSTANCE_DELIMITER) == -1
+        assert repr(dirname).find(consts.REPR_DELIMITER) != -1
+        assert repr(data).find(consts.REPR_DELIMITER) != -1
+        assert chop_instance_repr(dirname).find(consts.REPR_DELIMITER) == -1
+        assert chop_instance_repr(data).find(consts.REPR_DELIMITER) == -1
     
     def test_strfields(self):
-        pass
+        from clu.repr import strfields
+        
+        class Thingy(object):
+            
+            fields = ('yo', 'dogg', 'iheard', 'youlike')
+            
+            def __init__(self, **kwargs):
+                self.yo         = kwargs.pop('yo',      'YO')
+                self.dogg       = kwargs.pop('dogg',    'DOGG')
+                self.iheard     = kwargs.pop('iheard',  'IHEARD')
+                self._youlike   = kwargs.pop('youlike', 'YOULIKE')
+            
+            def youlike(self):
+                return getattr(self, '_youlike', None)
+            
+            def __repr__(self):
+                return strfields(self, type(self).fields, try_callables=True)
+        
+        t0 = Thingy()
+        assert repr(t0) == "yo=“YO”, dogg=“DOGG”, iheard=“IHEARD”, youlike=“YOULIKE”"
     
     def test_strfields_slotted_class(self):
         from clu.abstract import Slotted
@@ -111,7 +130,26 @@ class TestRepr(object):
         assert chop_instance_repr(data)    == chop_instance_repr(stringify(data,    None))
     
     def test_stringify(self):
-        pass
+        from clu.repr import stringify, chop_instance_repr
+        
+        class Thingy(object):
+            
+            fields = ('yo', 'dogg', 'iheard', 'youlike')
+            
+            def __init__(self, **kwargs):
+                self.yo         = kwargs.pop('yo',      'YO')
+                self.dogg       = kwargs.pop('dogg',    'DOGG')
+                self.iheard     = kwargs.pop('iheard',  'IHEARD')
+                self._youlike   = kwargs.pop('youlike', 'YOULIKE')
+            
+            def youlike(self):
+                return getattr(self, '_youlike', None)
+            
+            def __repr__(self):
+                return stringify(self, type(self).fields, try_callables=True)
+        
+        t0 = Thingy()
+        assert chop_instance_repr(t0) == "Thingy(yo=“YO”, dogg=“DOGG”, iheard=“IHEARD”, youlike=“YOULIKE”)"
     
     def test_stringify_slotted_class(self):
         from clu.abstract import Slotted
@@ -155,4 +193,4 @@ class TestRepr(object):
         export(test_lambda_qualname, 'yo_dogg')     # renames using provided string name
         
         assert repr(test_lambda) == f"<function test_lambda at {test_hex_id}>"
-        assert repr(test_lambda_qualname) == f"<function yo_dogg at {test_hex_id_qualname}>"
+        assert repr(test_lambda_qualname) == f"<function TestRepr.test_repr_lambdas.<locals>.yo_dogg at {test_hex_id_qualname}>"
